@@ -511,6 +511,22 @@
         <source>template host</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Cut</source>
+        <translation type="unfinished">Cut</translation>
+    </message>
+    <message>
+        <source>Log already exists!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
+    </message>
+    <message>
+        <source>No such service!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
@@ -1872,11 +1888,11 @@ Bitte Kofiguration prüfen und erneut versuchen.</translation>
     <name>RDListLogs</name>
     <message>
         <source>Select Log - User: </source>
-        <translation>Logbenutzer auswählen:</translation>
+        <translation type="obsolete">Logbenutzer auswählen:</translation>
     </message>
     <message>
         <source>Select Log</source>
-        <translation>Log auswählen</translation>
+        <translation type="unfinished">Log auswählen</translation>
     </message>
     <message>
         <source>NAME</source>
@@ -1898,6 +1914,10 @@ Bitte Kofiguration prüfen und erneut versuchen.</translation>
         <source>Cancel</source>
         <translation>Abbrechen</translation>
     </message>
+    <message>
+        <source>ALL</source>
+        <translation type="obsolete">ALLE</translation>
+    </message>
 </context>
 <context>
     <name>RDListSelector</name>
@@ -1918,6 +1938,29 @@ Bitte Kofiguration prüfen und erneut versuchen.</translation>
         <translation>Aktive Services</translation>
     </message>
 </context>
+<context>
+    <name>RDLogFilter</name>
+    <message>
+        <source>Service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Filter</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation type="unfinished">Löschen</translation>
+    </message>
+    <message>
+        <source>Show Only Recent Logs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ALL</source>
+        <translation type="unfinished">ALLE</translation>
+    </message>
+</context>
 <context>
     <name>RDLogLine</name>
     <message>
