@@ -2,9 +2,7 @@
 //
 // Abstract a Rivendell Log Manager Clock.
 //
-//   (C) Copyright 2002-2004,2008 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdclock.cpp,v 1.19.2.1 2008/11/30 00:32:56 fredg Exp $
+//   (C) Copyright 2002-2004,2008,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -160,7 +158,7 @@ bool RDClock::load()
   while(q->next()) {
     clock_events.push_back(RDEventLine());
     clock_events.back().setName(q->value(0).toString());
-    clock_events.back().setStartTime(q->value(1).toTime());
+    clock_events.back().setStartTime(QTime().addMSecs(q->value(1).toInt()));
     clock_events.back().setLength(q->value(2).toInt());
     clock_events.back().load();
   }
@@ -212,11 +210,10 @@ bool RDClock::save()
   delete q;
   for(unsigned i=0;i<clock_events.size();i++) {
     sql=QString().sprintf("insert into %s_CLK set EVENT_NAME=\"%s\",\
-                           START_TIME=\"%s\",LENGTH=%d",
+                           START_TIME=%d,LENGTH=%d",
 			  (const char *)clock_name_esc,
 			  (const char *)clock_events[i].name(),
-			  (const char *)clock_events[i].startTime().
-			      toString("hh:mm:ss"),
+			  QTime().msecsTo(clock_events[i].startTime()),
 			  clock_events[i].length());
     q=new RDSqlQuery(sql);
     delete q;
@@ -239,7 +236,7 @@ bool RDClock::insert(const QString &event_name,int line)
     clock_events.push_back(RDEventLine());
   }
   else {
-    vector<RDEventLine>::iterator it=clock_events.begin()+line;
+    std::vector<RDEventLine>::iterator it=clock_events.begin()+line;
     clock_events.insert(it,1,RDEventLine());
   }
   clock_events[line].setName(event_name);
@@ -250,7 +247,7 @@ bool RDClock::insert(const QString &event_name,int line)
 
 void RDClock::remove(int line)
 {
-  vector<RDEventLine>::iterator it=clock_events.begin()+line;
+  std::vector<RDEventLine>::iterator it=clock_events.begin()+line;
   clock_events.erase(it,it+1);
 }
 
@@ -317,7 +314,9 @@ bool RDClock::generateLog(int hour,const QString &logname,
   while(q->next()) {
     eventline.setName(q->value(0).toString());
     eventline.load();
-    eventline.setStartTime(q->value(1).toTime().addSecs(3600*hour));
+    //    eventline.setStartTime(q->value(1).toTime().addSecs(3600*hour));
+    eventline.setStartTime(QTime().addMSecs(q->value(1).toInt()).
+			   addSecs(3600*hour));
     eventline.setLength(q->value(2).toInt());
     eventline.generateLog(logname,svc_name,errors,artistsep,clock_name_esc);
     eventline.clear();
@@ -325,3 +324,12 @@ bool RDClock::generateLog(int hour,const QString &logname,
   delete q;
   return true;
 }
+
+
+QString RDClock::tableName(const QString &name)
+{
+  QString ret=name;
+  ret.replace(" ","_");
+
+  return ret+"_CLK";
+}
