@@ -2,9 +2,7 @@
 //
 // Escape non-valid characters in a string.
 //
-//   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdescape_string.cpp,v 1.17 2010/07/29 19:32:33 cvs Exp $
+//   (C) Copyright 2002-2005,2016-2017 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,6 +21,58 @@
 #include <vector>
 
 #include <rdescape_string.h>
+#include <qdatetime.h>
+
+/**
+ * RDCheckDateTime - Checks for QTime.isValid 
+ * @param time - QTime object
+ * @param format - QString representing time format e.g. HH:MM
+ * @return QString, "NULL" if not Valid else formatted Time String
+ */
+QString RDCheckDateTime(QTime const &time, QString const &format)
+{
+  QString checkedValue = "NULL";
+  
+  if(time.isValid())
+    checkedValue = "\"" + time.toString(format) + "\"";
+  
+  return checkedValue;
+  
+}
+
+/**
+ * RDCheckDateTime - Checks for QDateTime.isValid 
+ * @param datetime - QDateTime object
+ * @param format - QString representing date time format e.g. yyyy-mm-dd HH:MM
+ * @return QString, "NULL" if not Valid else formatted DateTime String
+ */
+QString RDCheckDateTime(QDateTime const &datetime, QString const &format)
+{
+  QString checkedValue = "NULL";
+  
+  if(datetime.isValid())
+    checkedValue = "\"" + datetime.toString(format) + "\"";
+  
+  return checkedValue;
+  
+}
+
+/**
+ * RDCheckDateTime - Checks for QDate.isValid 
+ * @param date - QDate object
+ * @param format - QString representing date format e.g. yyyy-mm-dd
+ * @return QString, "NULL" if not Valid else formatted Date String
+ */
+QString RDCheckDateTime(QDate const &date, QString const &format)
+{
+  QString checkedValue = "NULL";
+  
+  if(date.isValid())
+    checkedValue = "\"" + date.toString(format) + "\"";
+  
+  return checkedValue;
+  
+}
 
 QString RDEscapeString(QString const &str)
 {
@@ -46,10 +96,6 @@ QString RDEscapeString(QString const &str)
 	  res+=QString("\\\"");
 	  break;
 
-	case '´':
-	  res+=QString("\\´");
-	  break;
-
 	case '`':
 	  res+=QString("\\`");
 	  break;
@@ -100,39 +146,12 @@ QString RDEscapeString(QString const &str)
 	  break;
     }
   }
+
   return res;
 }
 
 
-
-QString RDEscapeStringSQLColumn(QString const &str)
+QString RDEscapeShellString(QString str)
 {
-  QString res;
-
-  for(unsigned i=0;i<str.length();i++) {
-    switch(((const char *)str)[i]) {
-        case 0:
-          res+=QString("\\0");
-          break;
-
-        case '/':
-          res+=QString("_");
-          break;
-
-        case '\\':
-          res+=QString("_");
-          break;
-
-        case '.':
-          res+=QString("_");
-          break;
-
-	default:
-	  res+=((const char *)str)[i];
-	  break;
-    }
-  }
-  return res;
+  return "\""+str.replace("$","\\$")+"\"";
 }
-
-
