@@ -2,9 +2,7 @@
 //
 // A dialog for displaying exception reports.
 //
-//   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdexception_dialog.h,v 1.3 2007-02-14 21:48:41 fredg Exp $
+//   (C) Copyright 2002-2005,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -26,12 +24,11 @@
 #include <qdialog.h>
 #include <qtextview.h>
 
-
 class RDExceptionDialog : public QDialog
 {
  Q_OBJECT
  public:
-  RDExceptionDialog(QString report,QWidget *parent=0,const char *name=0);
+  RDExceptionDialog(QString report,QWidget *parent=0);
   ~RDExceptionDialog();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
