@@ -2,9 +2,7 @@
 //
 // Edit Rivendell Service Permissions
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: edit_svc_perms.h,v 1.4 2007/09/14 14:06:27 fredg Exp $
+//   (C) Copyright 2002-2004,2016-2017 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -24,18 +22,17 @@
 #define EDIT_SVC_PERMS_H
 
 #include <qdialog.h>
-#include <qsqldatabase.h>
 
 #include <rdlistselector.h>
 
+#include <rddb.h>
 #include <rdsvc.h>
 
-
 class EditSvcPerms : public QDialog
 {
   Q_OBJECT
  public:
-  EditSvcPerms(RDSvc *svc,QWidget *parent=0,const char *name=0);
+  EditSvcPerms(RDSvc *svc,QWidget *parent=0);
   ~EditSvcPerms();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
@@ -50,5 +47,5 @@ class EditSvcPerms : public QDialog
 };
 
 
-#endif
+#endif  // EDIT_SVC_PERMS_H
 
