@@ -57,6 +57,21 @@
 #define RDCATCH_MAX_VISIBLE_MONITORS 8
 #define RDCATCH_USAGE "[--offline-host-warnings=yes|no]\n"
 
+class CatchConnector
+{
+ public:
+  CatchConnector(RDCatchConnect *conn,const QString &station_name);
+  RDCatchConnect *connector() const;
+  QString stationName();
+  std::vector<unsigned> chan;
+  std::vector<unsigned> mon_id;
+
+ private:
+  RDCatchConnect *catch_connect;
+  QString catch_station_name;
+};
+
+
 class MainWidget : public QWidget
 {
   Q_OBJECT
@@ -93,7 +108,7 @@ class MainWidget : public QWidget
   void selectionChangedData(QListViewItem *item);
   void doubleClickedData(QListViewItem *,const QPoint &,int);
   void filterChangedData(bool state);
-  void dowChangedData(int id);
+  void filterActivatedData(int id);
   void clockData();
   void midnightData();
   void eventUpdatedData(int id);
@@ -128,13 +143,7 @@ class MainWidget : public QWidget
   std::vector<CatchMonitor *> catch_monitor;
   QScrollView *catch_monitor_view;
   VBox *catch_monitor_vbox;
-  struct {
-    RDCatchConnect *connect;
-    QString station;
-    std::vector<unsigned> chan;
-    std::vector<unsigned> mon_id;
-  } catch_connect[RD_MAX_STATIONS];
-  int catch_station_count;
+  std::vector<CatchConnector *> catch_connect;
   QSqlDatabase *catch_db;
   int catch_audition_stream;
   int catch_play_handle;
@@ -153,12 +162,7 @@ class MainWidget : public QWidget
   QString catch_filter;
   QString catch_group;
   QString catch_schedcode;
-  QPixmap *catch_record_map;
-  QPixmap *catch_playout_map;
-  QPixmap *catch_macro_map;
-  QPixmap *catch_switch_map;
-  QPixmap *catch_download_map;
-  QPixmap *catch_upload_map;
+  QPixmap *catch_type_maps[RDRecording::LastType];
   QTimer *catch_next_timer;
   QPalette catch_scroll_color[2];
   bool catch_scroll;
@@ -170,6 +174,8 @@ class MainWidget : public QWidget
   QCheckBox *catch_show_today_box;
   QLabel *catch_dow_label;
   QComboBox *catch_dow_box;
+  QLabel *catch_type_label;
+  QComboBox *catch_type_box;
   QString catch_filter_string;
   QTimer *catch_midnight_timer;
   int catch_time_offset;
@@ -178,4 +184,4 @@ class MainWidget : public QWidget
 };
 
 
-#endif 
+#endif  // RDCATCH_H
