@@ -41,13 +41,13 @@
 #include <rdconf.h>
 #include <rddatedialog.h>
 
-#include <globals.h>
-#include <add_meta.h>
-#include <edit_log.h>
-#include <edit_logline.h>
-#include <edit_marker.h>
-#include <edit_track.h>
-#include <edit_chain.h>
+#include "globals.h"
+#include "add_meta.h"
+#include "edit_chain.h"
+#include "edit_log.h"
+#include "edit_logline.h"
+#include "edit_marker.h"
+#include "edit_track.h"
 
 //
 // Icons
@@ -144,7 +144,7 @@ EditLog::EditLog(QString logname,QString *filter,QString *group,
   //
   // Log Header
   //
-  edit_log=new RDLog(edit_logname,false);
+  edit_log=new RDLog(edit_logname);
 
   //
   // Log Events
@@ -529,16 +529,13 @@ EditLog::EditLog(QString logname,QString *filter,QString *group,
     edit_purgedate_box->setChecked(true);
     edit_purgedate_edit->setDate(purge_date);
   }
-  if (rdstation_conf->broadcastSecurity() == RDStation::UserSec) {
-    services_list = rduser->services();
-  } else { // RDStation::HostSec
-    sql=QString("select NAME from SERVICES");
-    q=new RDSqlQuery(sql);
-    while(q->next()) {
-      services_list.append( q->value(0).toString() );
-    }
-    delete q;
+  sql=QString("select NAME from SERVICES");
+  q=new RDSqlQuery(sql);
+  while(q->next()) {
+    services_list.append( q->value(0).toString() );
   }
+  delete q;
+
   int n=-1;
   int ncounter=0;
   QString service=edit_log->service();
@@ -1092,40 +1089,24 @@ void EditLog::saveasData()
   }
   QString logname;
   QString svcname=edit_service_box->currentText();
-  RDSqlQuery *q;
-  QString sql;
   RDAddLog *log=NULL;
+  QString err_msg;
 
   if(rduser->createLog()) {
-    if (rdstation_conf->broadcastSecurity() == RDStation::UserSec) {
-      log=new RDAddLog(&logname,&svcname,NULL,tr("Add Log"),this,rduser);
-    } else { // RDStation::HostSec
-      log=new RDAddLog(&logname,&svcname,NULL,tr("Add Log"),this);
-    }
+    log=new RDAddLog(&logname,&svcname,RDLogFilter::UserFilter,rduser,
+		     rdstation_conf,tr("Add Log"),this);
     if(log->exec()<0) {
       return;
     }
-    sql=QString().sprintf("insert into LOGS set \
-NAME=\"%s\",TYPE=0,DESCRIPTION=\"%s log\",ORIGIN_USER=\"%s\",\
-ORIGIN_DATETIME=NOW(),LINK_DATETIME=NOW(),SERVICE=\"%s\"",
-			  (const char *)logname,
-			  (const char *)logname,
-			  (const char *)rdripc->user(),
-			  (const char *)svcname);
-    q=new RDSqlQuery(sql);
-    if(!q->isActive()) {
-      QMessageBox::warning(this,tr("Log Exists"),tr("Log Already Exists!"));
-      delete q;
+    if(!RDLog::create(logname,svcname,rdripc->user(),&err_msg,log_config)) {
+      QMessageBox::warning(this,"RDLogEdit - "+tr("Error"),err_msg);
       return;
     }
-    delete q;
     delete edit_log;
     edit_newlogs->push_back(logname);
-    edit_log=new RDLog(logname,true);
-    QString logtable=logname;
-    logtable.replace(" ","_");
-    RDCreateLogTable(RDLog::tableName(logtable));
-    edit_log_event->setLogName(RDLog::tableName(logtable));
+    edit_log=new RDLog(logname);
+    RDCreateLogTable(RDLog::tableName(logname),log_config);
+    edit_log_event->setLogName(RDLog::tableName(logname));
     for(int i=0;i<edit_service_box->count();i++) {
       if(edit_service_box->text(i)==svcname) {
 	edit_service_box->setCurrentItem(i);
@@ -1391,7 +1372,7 @@ void EditLog::SaveLog()
     edit_log->setEndDate(QDate());
   }
   edit_log->setAutoRefresh(edit_autorefresh_box->currentItem()==0);
-  edit_log_event->save();
+  edit_log_event->save(log_config);
   edit_log->
     setModifiedDatetime(QDateTime(QDate::currentDate(),QTime::currentTime()));
 }
