@@ -36,6 +36,7 @@
 #include <qcombobox.h>
 #include <qlabel.h>
 
+#include <rdlogfilter.h>
 #include <rduser.h>
 #include <rdripc.h>
 #include <rdlibrary_conf.h>
@@ -61,7 +62,7 @@ class MainWidget : public QMainWindow
   void trackData();
   void reportData();
   void filterChangedData(const QString &str);
-  void filterClearedData();
+  void logSelectionChangedData();
   void logDoubleclickedData(QListViewItem *item,const QPoint &pt,int col);
   void quitMainWidget();
 
@@ -71,19 +72,15 @@ class MainWidget : public QMainWindow
  private:
   void RefreshItem(ListListViewItem *item);
   void RefreshList();
+  unsigned SelectedLogs(std::vector<ListListViewItem *> *items,
+			int *tracks=NULL) const;
   QSqlDatabase *log_db;
   QString log_filename;
   QString log_import_path;
   QLabel *log_user_label;
   int log_card_no;
   int log_stream_no;
-  QLabel *log_service_label;
-  QComboBox *log_service_box;
-  QLabel *log_filter_label;
-  QLineEdit *log_filter_edit;
-  QPushButton *log_filter_button;
-  QCheckBox *log_recent_check;
-  QLabel *log_recent_label;
+  RDLogFilter *log_filter_widget;
   QListView *log_log_list;
   std::vector<RDLogLine> log_clipboard;
   QPushButton *log_add_button;
