@@ -116,7 +116,7 @@ List</source>
     <message>
         <source>Are you sure you want to
 delete</source>
-        <translation>¿Realmente desea
+        <translation type="obsolete">¿Realmente desea
 eliminar</translation>
     </message>
     <message>
@@ -187,6 +187,15 @@ horario</translation>
         <source>Remarks</source>
         <translation>Comentarios</translation>
     </message>
+    <message>
+        <source>&amp;Clone</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete
+</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEvent</name>
@@ -518,6 +527,10 @@ Do you want to overwrite it?</source>
         <source>IMPORT</source>
         <translation>IMPORTAR</translation>
     </message>
+    <message>
+        <source>and code</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEventLine</name>
