@@ -2,9 +2,7 @@
 //
 // A Batch Importer for Rivendell.
 //
-//   (C) Copyright 2002-2009 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdimport.h,v 1.17.6.3.2.3 2014/07/15 00:45:17 cvs Exp $
+//   (C) Copyright 2002-2009,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,7 +18,6 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-
 #ifndef RDIMPORT_H
 #define RDIMPORT_H
 
@@ -57,7 +54,7 @@ class MainObject : public QObject
 {
   Q_OBJECT;
  public:
-  MainObject(QObject *parent=0,const char *name=0);
+  MainObject(QObject *parent=0);
 
  private slots:
   void userData();
@@ -81,6 +78,7 @@ class MainObject : public QObject
   QDateTime GetCachedTimestamp(const QString &filename);
   void WriteTimestampCache(const QString &filename,const QDateTime &dt);
   bool SchedulerCodeExists(const QString &code) const;
+  void ReadXmlFile(const QString &basename,RDWaveData *wavedata) const;
   RDConfig *import_config;
   RDCmdSwitch *import_cmd;
   unsigned import_file_key;
@@ -89,6 +87,7 @@ class MainObject : public QObject
   RDUser *import_user;
   bool import_verbose;
   bool import_log_mode;
+  bool import_to_mono;
   bool import_use_cartchunk_cutid;
   int import_cart_number_offset;
   bool import_single_cart;
@@ -110,6 +109,7 @@ class MainObject : public QObject
   bool import_clear_dayparts;
   bool import_fix_broken_formats;
   int import_persistent_dropbox_id;
+  bool import_xml;
   unsigned import_format;
   unsigned import_samprate;
   unsigned import_bitrate;
