@@ -28,7 +28,6 @@
 #include <rddb.h>
 #include <rdformpost.h>
 #include <rdweb.h>
-#include <rdsvc.h>
 #include <rduser.h>
 #include <rdlog.h>
 #include <rdlog_event.h>
@@ -52,10 +51,7 @@ void Xport::AddLog()
   if(!xport_post->getValue("SERVICE_NAME",&service_name)) {
     XmlExit("Missing SERVICE_NAME",400,"logs.cpp",LINE_NUMBER);
   }
-  RDSvc *svc=new RDSvc(service_name);
-  if(!svc->exists()) {
-    XmlExit("No such service",404,"logs.cpp",LINE_NUMBER);
-  }
+  GetLogService(service_name);
 
   //
   // Verify User Perms
@@ -64,21 +60,11 @@ void Xport::AddLog()
     XmlExit("Unauthorized",404,"logs.cpp",LINE_NUMBER);
   }
 
-  RDLog *log=new RDLog(log_name);
-  if(!log->exists()) {
-    delete log;
-    log=new RDLog(log_name,true);
-    if(!log->exists()) {
-      delete log;
-      XmlExit("Unable to create log",500,"logs.cpp",LINE_NUMBER);
-    }
-    log->setOriginUser(xport_user->name());
-    log->setDescription("[new log]");
-    log->setService(service_name);
+  QString err_msg;
+  if(!RDLog::create(log_name,service_name,xport_user->name(),&err_msg,
+		    xport_config)) {
+    XmlExit(err_msg,500,"logs.cpp",LINE_NUMBER);
   }
-  delete log;
-  RDCreateLogTable(RDLog::tableName(log_name));
-
   XmlExit("OK",200,"logs.cpp",LINE_NUMBER);
 }
 
@@ -122,32 +108,74 @@ void Xport::ListLogs()
   QString service_name="";
   QString log_name="";
   QString trackable;
+  QString filter="";
+  QString recent="";
 
   //
   // Get Options
   //
   xport_post->getValue("SERVICE_NAME",&service_name);
+  if(!service_name.isEmpty()) {
+    GetLogService(service_name);
+  }
   xport_post->getValue("LOG_NAME",&log_name);
   xport_post->getValue("TRACKABLE",&trackable);
+  xport_post->getValue("FILTER",&filter);
+  filter=filter.stripWhiteSpace();
+  xport_post->getValue("RECENT",&recent);
 
   //
   // Generate Log List
   //
   sql="select NAME from LOGS";
-  if((!service_name.isEmpty())||(!log_name.isEmpty())||(trackable=="1")) {
-    sql+=" where";
-    if(!log_name.isEmpty()) {
-      sql+=" (NAME=\""+RDEscapeString(log_name)+"\")&&";
-    }
-    if(!service_name.isEmpty()) {
-      sql+=" (SERVICE=\""+RDEscapeString(service_name)+"\")&&";
-    }
-    if(trackable=="1") {
-      sql+=" (SCHEDULED_TRACKS>0)&&";
+  sql+=" where";
+  if(!log_name.isEmpty()) {
+    sql+=" (NAME=\""+RDEscapeString(log_name)+"\")&&";
+  }
+  if(service_name.isEmpty()) {
+    QString sql2=QString("select SERVICE_NAME from USER_SERVICE_PERMS where ")+
+      "USER_NAME=\""+RDEscapeString(xport_user->name())+"\"";
+    q=new RDSqlQuery(sql2);
+    sql+="(";
+    while(q->next()) {
+      sql+="(SERVICE=\""+RDEscapeString(q->value(0).toString())+"\")||";
     }
     sql=sql.left(sql.length()-2);
+    sql+=")&&";
+    delete q;
+  }
+  else {
+    sql+=" (SERVICE=\""+RDEscapeString(service_name)+"\")&&";
+  }
+  if(trackable=="1") {
+    sql+=" (SCHEDULED_TRACKS>0)&&";
+  }
+  if(!filter.isEmpty()) {
+    if(service_name.isEmpty()) {
+      sql+=" ((LOGS.NAME like \"%%"+RDEscapeString(filter)+"%%\")||";
+      sql+="(LOGS.DESCRIPTION like \"%%"+RDEscapeString(filter)+"%%\")||";
+      sql+="(LOGS.SERVICE like \"%%"+RDEscapeString(filter)+"%%\"))&&";
+    }
+    else {
+      sql+=" ((LOGS.NAME like \"%%"+RDEscapeString(filter)+"%%\")||";
+      sql+="(LOGS.DESCRIPTION like \"%%"+RDEscapeString(filter)+"%%\"))&&";
+    }
+  }
+  sql=sql.stripWhiteSpace();
+  if(sql.right(2)=="&&") {
+    sql=sql.left(sql.length()-2);
+  }
+  sql=sql.stripWhiteSpace();
+  if(sql.right(5)=="where") {
+    sql=sql.left(sql.length()-5);
+  }
+  if(recent=="1") {
+    sql+=QString().sprintf(" order by LOGS.ORIGIN_DATETIME desc limit %d",
+			   RD_LOGFILTER_LIMIT_QUAN);
+  }
+  else {
+    sql+=" order by NAME";
   }
-  sql+=" order by NAME";
   q=new RDSqlQuery(sql);
 
   //
@@ -183,7 +211,7 @@ void Xport::ListLog()
   // Verify that log exists
   //
   log=new RDLog(name);
-  if(!log->exists()) {
+  if((!ServiceUserValid(log->service()))||(!log->exists())) {
     delete log;
     XmlExit("No such log",404,"logs.cpp",LINE_NUMBER);
   }
@@ -233,6 +261,7 @@ void Xport::SaveLog()
   if(!xport_post->getValue("SERVICE_NAME",&service_name)) {
     XmlExit("Missing SERVICE_NAME",400,"logs.cpp",LINE_NUMBER);
   }
+  GetLogService(service_name);
   if(!xport_post->getValue("DESCRIPTION",&description)) {
     XmlExit("Missing DESCRIPTION",400,"logs.cpp",LINE_NUMBER);
   }
@@ -473,8 +502,42 @@ void Xport::SaveLog()
   log->setEndDate(end_date);
   log->setModifiedDatetime(QDateTime::currentDateTime());
 
-  logevt->save();
+  logevt->save(xport_config);
 
   XmlExit(QString().sprintf("OK Saved %d events",logevt->size()),
 	  200,"logs.cpp",LINE_NUMBER);
 }
+
+
+RDSvc *Xport::GetLogService(const QString &svc_name)
+{
+  QString sql=QString("select SERVICE_NAME from USER_SERVICE_PERMS where ")+
+    "(USER_NAME=\""+RDEscapeString(xport_user->name())+"\")&&"+
+    "(SERVICE_NAME=\""+RDEscapeString(svc_name)+"\")";
+  RDSqlQuery *q=new RDSqlQuery(sql);
+  if(!q->first()) {
+    XmlExit("No such service",404,"logs.cpp",LINE_NUMBER);
+  }
+  delete q;
+  RDSvc *svc=new RDSvc(svc_name,xport_station,xport_config);
+  if(!svc->exists()) {
+    XmlExit("No such service",404,"logs.cpp",LINE_NUMBER);
+  }
+
+  return svc;
+}
+
+
+bool Xport::ServiceUserValid(const QString &svc_name)
+{
+  bool ret=false;
+
+  QString sql=QString("select SERVICE_NAME from USER_SERVICE_PERMS where ")+
+    "(SERVICE_NAME=\""+RDEscapeString(svc_name)+"\")&&"+
+    "(USER_NAME=\""+RDEscapeString(xport_user->name())+"\")";
+  RDSqlQuery *q=new RDSqlQuery(sql);
+  ret=q->first();
+  delete q;
+
+  return ret;
+}
